==> zio-aws-chimesdkmessaging_2.13-5.17.113.1-sources.jar: zio/aws/chimesdkmessaging/model/DescribeChannelBanResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeChannelBanResponse(
    channelBan: Option[zio.aws.chimesdkmessaging.model.ChannelBan] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse = {
    import DescribeChannelBanResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
      .builder()
      .optionallyWith(channelBan.map(value => value.buildAwsValue()))(
        _.channelBan
      )
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse
      .wrap(buildAwsValue())
}
object DescribeChannelBanResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse =
      zio.aws.chimesdkmessaging.model
        .DescribeChannelBanResponse(channelBan.map(value => value.asEditable))
    def channelBan: Option[zio.aws.chimesdkmessaging.model.ChannelBan.ReadOnly]
    def getChannelBan: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelBan.ReadOnly
    ] = AwsError.unwrapOptionField("channelBan", channelBan)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
  ) extends zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse.ReadOnly {
    override val channelBan
        : Option[zio.aws.chimesdkmessaging.model.ChannelBan.ReadOnly] = scala
      .Option(impl.channelBan())
      .map(value => zio.aws.chimesdkmessaging.model.ChannelBan.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
  ): zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-6.20.103.1-sources.jar: zio/aws/chimesdkmessaging/model/DescribeChannelBanResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeChannelBanResponse(
    channelBan: Optional[zio.aws.chimesdkmessaging.model.ChannelBan] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse = {
    import DescribeChannelBanResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
      .builder()
      .optionallyWith(channelBan.map(value => value.buildAwsValue()))(
        _.channelBan
      )
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse
      .wrap(buildAwsValue())
}
object DescribeChannelBanResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse =
      zio.aws.chimesdkmessaging.model
        .DescribeChannelBanResponse(channelBan.map(value => value.asEditable))
    def channelBan
        : Optional[zio.aws.chimesdkmessaging.model.ChannelBan.ReadOnly]
    def getChannelBan: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelBan.ReadOnly
    ] = AwsError.unwrapOptionField("channelBan", channelBan)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
  ) extends zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse.ReadOnly {
    override val channelBan
        : Optional[zio.aws.chimesdkmessaging.model.ChannelBan.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.channelBan())
        .map(value => zio.aws.chimesdkmessaging.model.ChannelBan.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelBanResponse
  ): zio.aws.chimesdkmessaging.model.DescribeChannelBanResponse.ReadOnly =
    new Wrapper(impl)
}
